MarkerAnimator class
Class to animate markers on a Mapbox map.
- Inheritance
-
- Object
- TickerProvider
- MarkerAnimator
Constructors
- MarkerAnimator(MapboxMap mapboxMap)
- Constructor to initialize the MarkerAnimator with the MapboxMap instance.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mapboxMap → MapboxMap
-
final
-
markerLayerIds
→ Map<
String, String> -
final
-
markerPoints
→ Map<
String, List< Map< >String, dynamic> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addMarkerPoint(
String markerId, String markerImage, List< Map< data, {int animationDuration = 50, double scale = 15, Map<String, dynamic> >String, dynamic> properties = const {"icon-opacity" : 1.0, "icon-size" : 1.0, "icon-anchor" : "center", "icon-offset" : [0.5, 0.5], 'icon-allow-overlap' : true, 'icon-ignore-placement' : true}, Curve positionCurve = Curves.linear, Curve rotationCurve = Curves.linear}) → Future<void> - Adds a marker marker to the map and animates it between points.
-
createTicker(
TickerCallback onTick) → Ticker -
Creates a ticker with the given callback.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeMarker(
String markerId) → Future< void> - Removes a marker marker from the map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited